@@ -2,7 +2,7 @@ use crate::expr::Expr;
 use crate::table_expr::TableExpr;
 
 #[derive(Clone, Copy, Debug, Default, PartialEq, Eq)]
-pub struct Ident<'a>(pub(crate) &'a str);
+pub struct Ident<'a>(pub &'a str);
 
 crate::macros::gen_display!(Ident<'_>);
 
@@ -13,6 +13,17 @@ impl<'a> std::convert::From<&'a str> for Ident<'a> {
     }
 }
 
+impl<'a> std::convert::From<ColumnRef<'a>> for Ident<'a> {
+    #[inline]
+    fn from(val: ColumnRef<'a>) -> Self {
+        match val {
+            ColumnRef::Column(col) => col,
+            ColumnRef::TableColumn(.., col) => col,
+            ColumnRef::SchemaTableColumn(.., col) => col,
+        }
+    }
+}
+
 #[allow(clippy::enum_variant_names)]
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub enum ColumnRef<'a> {
